@@ -1,8 +1,8 @@
 """
-'Quickly check whether there is a visible difference between two PDFs, using ImageMagick and pdftocairo.
+Quickly check whether there is a visible difference between two PDFs, using ImageMagick and pdftocairo.
 """
 
-__version__ = '1.6.0'
+__version__ = '1.6.3'
 
 from typing import List
 
